@@ -23,7 +23,6 @@ from oslo_policy import policy
 from oslo_utils import excutils
 
 from heat.common import exception
-from heat.common.i18n import _
 from heat import policies
 
 
@@ -48,6 +47,9 @@ class Enforcer(object):
             CONF, default_rule=default_rule, policy_file=policy_file)
         self.log_not_registered = True
 
+        # TODO(ramishra) Remove this once remove the deprecated rules.
+        self.enforcer.suppress_deprecation_warnings = True
+
         # register rules
         self.enforcer.register_defaults(policies.list_rules())
         self.file_rules = self.enforcer.file_rules
@@ -75,20 +77,29 @@ class Enforcer(object):
         """
         do_raise = False if not exc else True
         credentials = context.to_policy_values()
-        if is_registered_policy:
-            try:
-                return self.enforcer.authorize(rule, target, credentials,
-                                               do_raise=do_raise,
-                                               exc=exc, action=rule)
-            except policy.PolicyNotRegistered:
-                if self.log_not_registered:
-                    with excutils.save_and_reraise_exception():
-                        LOG.exception(_('Policy not registered.'))
-                else:
-                    raise
-        else:
-            return self.enforcer.enforce(rule, target, credentials,
-                                         do_raise, exc=exc, *args, **kwargs)
+
+        try:
+            if is_registered_policy:
+                try:
+                    return self.enforcer.authorize(rule, target, credentials,
+                                                   do_raise=do_raise,
+                                                   exc=exc, action=rule)
+                except policy.PolicyNotRegistered:
+                    if self.log_not_registered:
+                        with excutils.save_and_reraise_exception():
+                            LOG.exception('Policy not registered.')
+                    else:
+                        raise
+            else:
+                return self.enforcer.enforce(rule, target, credentials,
+                                             do_raise, exc=exc, *args,
+                                             **kwargs)
+        except policy.InvalidScope:
+            LOG.debug('Policy check for %(action)s failed with scope check '
+                      '%(credentials)s',
+                      {'action': rule,
+                       'credentials': context.to_policy_values()})
+            raise exc(action=rule)
 
     def enforce(self, context, action, scope=None, target=None,
                 is_registered_policy=False):
@@ -178,6 +189,6 @@ class ResourceEnforcer(Enforcer):
 
     def enforce_stack(self, stack, scope=None, target=None,
                       is_registered_policy=False):
-        for res in stack.resources.values():
-            self.enforce(stack.context, res.type(), scope=scope, target=target,
+        for res_type in stack.defn.all_resource_types():
+            self.enforce(stack.context, res_type, scope=scope, target=target,
                          is_registered_policy=is_registered_policy)
