@@ -21,17 +21,14 @@ from oslo_config import cfg
 from oslo_utils import excutils
 
 import requests
-import six
 
 from heat.common import config
-from heat.common import context
 from heat.common import exception as heat_exception
 
 cfg.CONF.import_opt('client_retry_limit', 'heat.common.config')
 
 
-@six.add_metaclass(abc.ABCMeta)
-class ClientPlugin(object):
+class ClientPlugin(object, metaclass=abc.ABCMeta):
 
     # Module which contains all exceptions classes which the client
     # may emit
@@ -50,6 +47,7 @@ class ClientPlugin(object):
         self._context = weakref.ref(context)
         self._clients = weakref.ref(context.clients)
         self._client_instances = {}
+        self._endpoint_existence = {}
 
     @property
     def context(self):
@@ -89,12 +87,18 @@ class ClientPlugin(object):
         pass
 
     def _get_region_name(self):
-        return self.context.region_name or cfg.CONF.region_name_for_services
+        reg = self.context.region_name or cfg.CONF.region_name_for_services
+        # If Shared Services configured, override region for image/volumes
+        shared_services_region_name = cfg.CONF.region_name_for_shared_services
+        shared_services_types = cfg.CONF.shared_services_types
+        if shared_services_region_name:
+            if set(self.service_types) & set(shared_services_types):
+                reg = shared_services_region_name
+        return reg
 
     def url_for(self, **kwargs):
         keystone_session = self.context.keystone_session
 
-        @context.retry_on_connection_timeout
         def get_endpoint():
             return keystone_session.get_endpoint(**kwargs)
 
@@ -133,11 +137,10 @@ class ClientPlugin(object):
         if self.exceptions_module:
             if isinstance(self.exceptions_module, list):
                 for m in self.exceptions_module:
-                    if type(ex) in six.itervalues(m.__dict__):
+                    if type(ex) in m.__dict__.values():
                         return True
             else:
-                return type(ex) in six.itervalues(
-                    self.exceptions_module.__dict__)
+                return type(ex) in self.exceptions_module.__dict__.values()
         return False
 
     def is_not_found(self, ex):
@@ -165,14 +168,18 @@ class ClientPlugin(object):
     def does_endpoint_exist(self,
                             service_type,
                             service_name):
-        endpoint_type = self._get_client_option(service_name,
-                                                'endpoint_type')
-        try:
-            self.url_for(service_type=service_type,
-                         endpoint_type=endpoint_type)
-            return True
-        except exceptions.EndpointNotFound:
-            return False
+        endpoint_key = (service_type, service_name)
+        if endpoint_key not in self._endpoint_existence:
+            endpoint_type = self._get_client_option(service_name,
+                                                    'endpoint_type')
+            try:
+                self.url_for(service_type=service_type,
+                             endpoint_type=endpoint_type)
+                self._endpoint_existence[endpoint_key] = True
+            except exceptions.EndpointNotFound:
+                self._endpoint_existence[endpoint_key] = False
+
+        return self._endpoint_existence[endpoint_key]
 
 
 def retry_if_connection_err(exception):
