@@ -31,7 +31,8 @@ from heat.engine import function
 
 LOG = logging.getLogger(__name__)
 
-opts = [
+yaql_group = cfg.OptGroup('yaql')
+yaql_opts = [
     cfg.IntOpt('limit_iterators',
                default=200,
                help=_('The maximum number of elements in collection '
@@ -41,7 +42,11 @@ opts = [
                help=_('The maximum size of memory in bytes that '
                       'expression can take for its evaluation.'))
 ]
-cfg.CONF.register_opts(opts, group='yaql')
+cfg.CONF.register_opts(yaql_opts, group=yaql_group)
+
+
+def list_opts():
+    yield yaql_group.name, yaql_opts
 
 
 class GetParam(function.Function):
@@ -79,7 +84,7 @@ class GetParam(function.Function):
         if isinstance(args, str):
             param_name = args
             path_components = []
-        elif isinstance(args, collections.Sequence):
+        elif isinstance(args, collections.abc.Sequence):
             param_name = args[0]
             path_components = args[1:]
         else:
@@ -96,15 +101,15 @@ class GetParam(function.Function):
             raise exception.UserParameterMissing(key=param_name)
 
         def get_path_component(collection, key):
-            if not isinstance(collection, (collections.Mapping,
-                                           collections.Sequence)):
+            if not isinstance(collection, (collections.abc.Mapping,
+                                           collections.abc.Sequence)):
                 raise TypeError(_('"%s" can\'t traverse path') % self.fn_name)
 
             if not isinstance(key, (str, int)):
                 raise TypeError(_('Path components in "%s" '
                                   'must be strings') % self.fn_name)
 
-            if isinstance(collection, collections.Sequence
+            if isinstance(collection, collections.abc.Sequence
                           ) and isinstance(key, str):
                 try:
                     key = int(key)
@@ -167,7 +172,7 @@ class GetAttThenSelect(function.Function):
          self._path_components) = self._parse_args()
 
     def _parse_args(self):
-        if (not isinstance(self.args, collections.Sequence) or
+        if (not isinstance(self.args, collections.abc.Sequence) or
                 isinstance(self.args, str)):
             raise TypeError(_('Argument to "%s" must be a list') %
                             self.fn_name)
@@ -314,7 +319,7 @@ class GetAttAllAttributes(GetAtt):
                                'forms: [resource_name] or '
                                '[resource_name, attribute, (path), ...]'
                                ) % self.fn_name)
-        elif isinstance(self.args, collections.Sequence):
+        elif isinstance(self.args, collections.abc.Sequence):
             if len(self.args) > 1:
                 return super(GetAttAllAttributes, self)._parse_args()
             else:
@@ -372,12 +377,12 @@ class Replace(function.Function):
 
         self._mapping, self._string = self._parse_args()
         if not isinstance(self._mapping,
-                          (collections.Mapping, function.Function)):
+                          (collections.abc.Mapping, function.Function)):
             raise TypeError(_('"%s" parameters must be a mapping') %
                             self.fn_name)
 
     def _parse_args(self):
-        if not isinstance(self.args, collections.Mapping):
+        if not isinstance(self.args, collections.abc.Mapping):
             raise TypeError(_('Arguments to "%s" must be a map') %
                             self.fn_name)
 
@@ -418,7 +423,7 @@ class Replace(function.Function):
         if not isinstance(template, str):
             raise TypeError(_('"%s" template must be a string') % self.fn_name)
 
-        if not isinstance(mapping, collections.Mapping):
+        if not isinstance(mapping, collections.abc.Mapping):
             raise TypeError(_('"%s" params must be a map') % self.fn_name)
 
         def replace(strings, keys):
@@ -490,9 +495,10 @@ class ReplaceJson(Replace):
             else:
                 _raise_empty_param_value_error()
 
-        if not isinstance(value, (str, int,
-                                  float, bool)):
-            if isinstance(value, (collections.Mapping, collections.Sequence)):
+        if not isinstance(value, (str, int, float, bool)):
+            if isinstance(
+                value, (collections.abc.Mapping, collections.abc.Sequence)
+            ):
                 if not self._allow_empty_value and len(value) == 0:
                     _raise_empty_param_value_error()
                 try:
@@ -604,7 +610,7 @@ class Join(function.Function):
         if strings is None:
             strings = []
         if (isinstance(strings, str) or
-                not isinstance(strings, collections.Sequence)):
+                not isinstance(strings, collections.abc.Sequence)):
             raise TypeError(_('"%s" must operate on a list') % self.fn_name)
 
         delim = function.resolve(self._delim)
@@ -669,7 +675,7 @@ class JoinMultiple(function.Function):
         for jl in r_joinlists:
             if jl:
                 if (isinstance(jl, str) or
-                        not isinstance(jl, collections.Sequence)):
+                        not isinstance(jl, collections.abc.Sequence)):
                     raise TypeError(_('"%s" must operate on '
                                       'a list') % self.fn_name)
 
@@ -687,7 +693,9 @@ class JoinMultiple(function.Function):
                 return ''
             elif isinstance(s, str):
                 return s
-            elif isinstance(s, (collections.Mapping, collections.Sequence)):
+            elif isinstance(
+                s, (collections.abc.Mapping, collections.abc.Sequence)
+            ):
                 try:
                     return jsonutils.dumps(s, default=None, sort_keys=True)
                 except TypeError:
@@ -725,17 +733,19 @@ class MapMerge(function.Function):
     def result(self):
         args = function.resolve(self.args)
 
-        if not isinstance(args, collections.Sequence):
+        if not isinstance(args, collections.abc.Sequence):
             raise TypeError(_('Incorrect arguments to "%(fn_name)s" '
                               'should be: %(example)s') % self.fmt_data)
 
         def ensure_map(m):
             if m is None:
                 return {}
-            elif isinstance(m, collections.Mapping):
+            elif isinstance(m, collections.abc.Mapping):
                 return m
             else:
-                msg = _('Incorrect arguments: Items to merge must be maps.')
+                msg = _('Incorrect arguments: Items to merge must be maps. '
+                        '{} is type {} instead of a dict'.format(
+                            repr(m)[:200], type(m)))
                 raise TypeError(msg)
 
         ret_map = {}
@@ -776,7 +786,7 @@ class MapReplace(function.Function):
         def ensure_map(m):
             if m is None:
                 return {}
-            elif isinstance(m, collections.Mapping):
+            elif isinstance(m, collections.abc.Mapping):
                 return m
             else:
                 msg = (_('Incorrect arguments: to "%(fn_name)s", arguments '
@@ -901,7 +911,7 @@ class Repeat(function.Function):
         self._parse_args()
 
     def _parse_args(self):
-        if not isinstance(self.args, collections.Mapping):
+        if not isinstance(self.args, collections.abc.Mapping):
             raise TypeError(_('Arguments to "%s" must be a map') %
                             self.fn_name)
 
@@ -923,12 +933,12 @@ class Repeat(function.Function):
         super(Repeat, self).validate()
 
         if not isinstance(self._for_each, function.Function):
-            if not isinstance(self._for_each, collections.Mapping):
+            if not isinstance(self._for_each, collections.abc.Mapping):
                 raise TypeError(_('The "for_each" argument to "%s" must '
                                   'contain a map') % self.fn_name)
 
     def _valid_arg(self, arg):
-        if not (isinstance(arg, (collections.Sequence,
+        if not (isinstance(arg, (collections.abc.Sequence,
                                  function.Function)) and
                 not isinstance(arg, str)):
             raise TypeError(_('The values of the "for_each" argument to '
@@ -939,10 +949,10 @@ class Repeat(function.Function):
             for (key, value) in zip(keys, values):
                 template = template.replace(key, value)
             return template
-        elif isinstance(template, collections.Sequence):
+        elif isinstance(template, collections.abc.Sequence):
             return [self._do_replacement(keys, values, elem)
                     for elem in template]
-        elif isinstance(template, collections.Mapping):
+        elif isinstance(template, collections.abc.Mapping):
             return dict((self._do_replacement(keys, values, k),
                          self._do_replacement(keys, values, v))
                         for (k, v) in template.items())
@@ -993,8 +1003,8 @@ class RepeatWithMap(Repeat):
     """
 
     def _valid_arg(self, arg):
-        if not (isinstance(arg, (collections.Sequence,
-                                 collections.Mapping,
+        if not (isinstance(arg, (collections.abc.Sequence,
+                                 collections.abc.Mapping,
                                  function.Function)) and
                 not isinstance(arg, str)):
             raise TypeError(_('The values of the "for_each" argument to '
@@ -1118,7 +1128,7 @@ class StrSplit(function.Function):
                          'example': example}
         self.fn_name = fn_name
 
-        if isinstance(args, (str, collections.Mapping)):
+        if isinstance(args, (str, collections.abc.Mapping)):
             raise TypeError(_('Incorrect arguments to "%(fn_name)s" '
                               'should be: %(example)s') % self.fmt_data)
 
@@ -1188,7 +1198,7 @@ class Yaql(function.Function):
     def __init__(self, stack, fn_name, args):
         super(Yaql, self).__init__(stack, fn_name, args)
 
-        if not isinstance(self.args, collections.Mapping):
+        if not isinstance(self.args, collections.abc.Mapping):
             raise TypeError(_('Arguments to "%s" must be a map.') %
                             self.fn_name)
 
@@ -1275,13 +1285,16 @@ class If(function.Macro):
     evaluates to false.
     """
 
+    def _read_args(self):
+        return self.args
+
     def parse_args(self, parse_func):
         try:
             if (not self.args or
-                    not isinstance(self.args, collections.Sequence) or
+                    not isinstance(self.args, collections.abc.Sequence) or
                     isinstance(self.args, str)):
                 raise ValueError()
-            condition, value_if_true, value_if_false = self.args
+            condition, value_if_true, value_if_false = self._read_args()
         except ValueError:
             msg = _('Arguments to "%s" must be of the form: '
                     '[condition_name, value_if_true, value_if_false]')
@@ -1299,6 +1312,40 @@ class If(function.Macro):
         return self.template.conditions(self.stack).is_enabled(cond)
 
 
+class IfNullable(If):
+    """A function to return corresponding value based on condition evaluation.
+
+    Takes the form::
+
+        if:
+          - <condition_name>
+          - <value_if_true>
+          - <value_if_false>
+
+    The value_if_true to be returned if the specified condition evaluates
+    to true, the value_if_false to be returned if the specified condition
+    evaluates to false.
+
+    If the value_if_false is omitted and the condition is false, the enclosing
+    item (list item, dictionary key/value pair, property definition) will be
+    treated as if it were not mentioned in the template::
+
+        if:
+          - <condition_name>
+          - <value_if_true>
+    """
+
+    def _read_args(self):
+        if not (2 <= len(self.args) <= 3):
+            raise ValueError()
+
+        if len(self.args) == 2:
+            condition, value_if_true = self.args
+            return condition, value_if_true, Ellipsis
+
+        return self.args
+
+
 class ConditionBoolean(function.Function):
     """Abstract parent class of boolean condition functions."""
 
@@ -1307,7 +1354,7 @@ class ConditionBoolean(function.Function):
         self._check_args()
 
     def _check_args(self):
-        if not (isinstance(self.args, collections.Sequence) and
+        if not (isinstance(self.args, collections.abc.Sequence) and
                 not isinstance(self.args, str)):
             msg = _('Arguments to "%s" must be a list of conditions')
             raise ValueError(msg % self.fn_name)
@@ -1402,7 +1449,7 @@ class Filter(function.Function):
         self._values, self._sequence = self._parse_args()
 
     def _parse_args(self):
-        if (not isinstance(self.args, collections.Sequence) or
+        if (not isinstance(self.args, collections.abc.Sequence) or
                 isinstance(self.args, str)):
             raise TypeError(_('Argument to "%s" must be a list') %
                             self.fn_name)
@@ -1427,7 +1474,8 @@ class Filter(function.Function):
             return sequence
         if not isinstance(values, list):
             raise TypeError(
-                _('"%(fn)s" filters a list of values') % self.fn_name)
+                _('"%(fn)s" filters a list of values') %
+                {'fn': self.fn_name})
         return [i for i in sequence if i not in values]
 
 
@@ -1464,7 +1512,7 @@ class MakeURL(function.Function):
             if arg in args:
                 if arg == self.QUERY:
                     if not isinstance(args[arg], (function.Function,
-                                                  collections.Mapping)):
+                                                  collections.abc.Mapping)):
                         raise TypeError(_('The "%(arg)s" argument to '
                                           '"%(fn_name)s" must be a map') %
                                         {'arg': arg,
@@ -1499,7 +1547,7 @@ class MakeURL(function.Function):
     def validate(self):
         super(MakeURL, self).validate()
 
-        if not isinstance(self.args, collections.Mapping):
+        if not isinstance(self.args, collections.abc.Mapping):
             raise TypeError(_('The arguments to "%s" must '
                               'be a map') % self.fn_name)
 
@@ -1582,14 +1630,14 @@ class ListConcat(function.Function):
         args = function.resolve(self.args)
 
         if (isinstance(args, str) or
-                not isinstance(args, collections.Sequence)):
+                not isinstance(args, collections.abc.Sequence)):
             raise TypeError(_('Incorrect arguments to "%(fn_name)s" '
                               'should be: %(example)s') % self.fmt_data)
 
         def ensure_list(m):
             if m is None:
                 return []
-            elif (isinstance(m, collections.Sequence) and
+            elif (isinstance(m, collections.abc.Sequence) and
                   not isinstance(m, str)):
                 return m
             else:
@@ -1603,12 +1651,14 @@ class ListConcat(function.Function):
         for m in args:
             ret_list.extend(ensure_list(m))
 
-        if self._unique:
-            for i in ret_list:
-                while ret_list.count(i) > 1:
-                    del ret_list[ret_list.index(i)]
+        if not self._unique:
+            return ret_list
 
-        return ret_list
+        unique_list = []
+        for item in ret_list:
+            if item not in unique_list:
+                unique_list.append(item)
+        return unique_list
 
 
 class ListConcatUnique(ListConcat):
@@ -1654,7 +1704,7 @@ class Contains(function.Function):
         resolved_value = function.resolve(self.value)
         resolved_sequence = function.resolve(self.sequence)
 
-        if not isinstance(resolved_sequence, collections.Sequence):
+        if not isinstance(resolved_sequence, collections.abc.Sequence):
             raise TypeError(_('Second argument to "%s" should be '
                               'a sequence.') % self.fn_name)
 
