@@ -14,6 +14,7 @@
 import itertools
 import uuid
 
+from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
 from oslo_utils import timeutils
@@ -23,7 +24,7 @@ from urllib import parse
 from heat.common import crypt
 from heat.common import exception
 from heat.common.i18n import _
-from heat.db.sqlalchemy import api as db_api
+from heat.db import api as db_api
 from heat.engine import api
 from heat.engine import resource
 from heat.engine import scheduler
@@ -35,6 +36,8 @@ from heat.rpc import api as rpc_api
 
 LOG = logging.getLogger(__name__)
 
+cfg.CONF.import_opt('metadata_put_timeout', 'heat.common.config')
+
 
 class SoftwareConfigService(object):
 
@@ -52,6 +55,9 @@ class SoftwareConfigService(object):
                   for sc in scs]
         return result
 
+    def count_software_config(self, cnxt):
+        return software_config_object.SoftwareConfig.count_all(cnxt)
+
     def create_software_config(self, cnxt, group, name, config,
                                inputs, outputs, options):
 
@@ -69,7 +75,7 @@ class SoftwareConfigService(object):
                 rpc_api.SOFTWARE_CONFIG_OPTIONS: options,
                 rpc_api.SOFTWARE_CONFIG_CONFIG: config
             },
-            'tenant': cnxt.tenant_id})
+            'tenant': cnxt.project_id})
         return api.format_software_config(sc)
 
     def delete_software_config(self, cnxt, config_id):
@@ -81,6 +87,10 @@ class SoftwareConfigService(object):
         result = [api.format_software_deployment(sd) for sd in all_sd]
         return result
 
+    def count_software_deployment(self, cnxt):
+        return software_deployment_object.SoftwareDeployment.count_all(
+            cnxt)
+
     def metadata_software_deployments(self, cnxt, server_id):
         if not server_id:
             raise ValueError(_('server_id must be specified'))
@@ -101,7 +111,6 @@ class SoftwareConfigService(object):
         rs = db_api.resource_get_by_physical_resource_id(cnxt, server_id)
         if not rs:
             return
-        cnxt.session.refresh(rs)
         if rs.action == resource.Resource.DELETE:
             return
         deployments = self.metadata_software_deployments(cnxt, server_id)
@@ -129,10 +138,11 @@ class SoftwareConfigService(object):
 
         if metadata_put_url:
             json_md = jsonutils.dumps(md)
-            resp = requests.put(metadata_put_url, json_md)
             try:
+                resp = requests.put(metadata_put_url, json_md,
+                                    timeout=cfg.CONF.metadata_put_timeout)
                 resp.raise_for_status()
-            except requests.HTTPError as exc:
+            except requests.RequestException as exc:
                 LOG.error('Failed to deliver deployment data to '
                           'server %s: %s', server_id, exc)
         if metadata_queue_id:
@@ -268,7 +278,11 @@ class SoftwareConfigService(object):
                                    input_values, action, status,
                                    status_reason, stack_user_project_id,
                                    deployment_id=None):
-
+        if stack_user_project_id is not None:
+            if len(stack_user_project_id) > 64:
+                raise exception.Invalid(
+                    reason='"stack_user_project_id" '
+                           'should be no more than 64 characters')
         if deployment_id is None:
             deployment_id = str(uuid.uuid4())
         sd = software_deployment_object.SoftwareDeployment.create(cnxt, {
@@ -276,7 +290,7 @@ class SoftwareConfigService(object):
             'config_id': config_id,
             'server_id': server_id,
             'input_values': input_values,
-            'tenant': cnxt.tenant_id,
+            'tenant': cnxt.project_id,
             'stack_user_project_id': stack_user_project_id,
             'action': action,
             'status': status,
