@@ -22,7 +22,7 @@ from oslo_versionedobjects import fields
 from heat.common import exception
 from heat.common.i18n import _
 from heat.common import identifier
-from heat.db.sqlalchemy import api as db_api
+from heat.db import api as db_api
 from heat.objects import base as heat_base
 from heat.objects import fields as heat_fields
 from heat.objects import raw_template
