@@ -10,20 +10,21 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import queue
 from unittest import mock
 import uuid
 
-import eventlet.queue
 from oslo_config import cfg
 from oslo_messaging import conffixture
 from oslo_messaging.rpc import dispatcher
 
+from heat.common import context
 from heat.common import environment_util as env_util
 from heat.common import exception
 from heat.common import messaging
 from heat.common import service_utils
 from heat.common import template_format
-from heat.db.sqlalchemy import api as db_api
+from heat.db import api as db_api
 from heat.engine.clients.os import glance
 from heat.engine.clients.os import nova
 from heat.engine.clients.os import swift
@@ -45,6 +46,7 @@ class ServiceStackUpdateTest(common.HeatTestCase):
     def setUp(self):
         super(ServiceStackUpdateTest, self).setUp()
         self.useFixture(conffixture.ConfFixture(cfg.CONF))
+        self.patchobject(context, 'StoredContext')
         self.ctx = utils.dummy_context()
         self.man = service.EngineService('a-host', 'a-topic')
         self.man.thread_group_mgr = tools.DummyThreadGroupManager()
@@ -70,8 +72,8 @@ class ServiceStackUpdateTest(common.HeatTestCase):
 
         mock_validate = self.patchobject(stk, 'validate', return_value=None)
         msgq_mock = mock.Mock()
-        self.patchobject(eventlet.queue, 'LightQueue',
-                         side_effect=[msgq_mock, eventlet.queue.LightQueue()])
+        self.patchobject(queue, 'Queue',
+                         side_effect=[msgq_mock, queue.Queue()])
 
         # do update
         api_args = {'timeout_mins': 60, rpc_api.PARAM_CONVERGE: True}
@@ -99,11 +101,12 @@ class ServiceStackUpdateTest(common.HeatTestCase):
             strict_validate=True,
             tenant_id='test_tenant_id',
             timeout_mins=60,
-            user_creds_id=u'1',
+            user_creds_id='1',
             username='test_username',
             converge=True
         )
-        mock_load.assert_called_once_with(self.ctx, stack=s)
+        mock_load.assert_called_once_with(self.ctx, stack=s,
+                                          check_refresh_cred=True)
         mock_validate.assert_called_once_with()
 
     def _test_stack_update_with_environment_files(self, stack_name,
@@ -124,9 +127,9 @@ class ServiceStackUpdateTest(common.HeatTestCase):
         self.patchobject(templatem, 'Template', return_value=stk.t)
         self.patchobject(environment, 'Environment', return_value=stk.env)
         self.patchobject(stk, 'validate', return_value=None)
-        self.patchobject(eventlet.queue, 'LightQueue',
+        self.patchobject(queue, 'Queue',
                          side_effect=[mock.Mock(),
-                                      eventlet.queue.LightQueue()])
+                                      queue.Queue()])
 
         mock_merge = self.patchobject(env_util, 'merge_environments')
 
@@ -189,8 +192,9 @@ class ServiceStackUpdateTest(common.HeatTestCase):
 
         mock_validate = self.patchobject(stk, 'validate', return_value=None)
         msgq_mock = mock.Mock()
-        self.patchobject(eventlet.queue, 'LightQueue',
-                         side_effect=[msgq_mock, eventlet.queue.LightQueue()])
+        self.patchobject(queue, 'Queue',
+                         side_effect=[msgq_mock,
+                                      queue.Queue()])
 
         # do update
         api_args = {'timeout_mins': 60, rpc_api.PARAM_CONVERGE: False}
@@ -218,11 +222,12 @@ class ServiceStackUpdateTest(common.HeatTestCase):
             strict_validate=True,
             tenant_id='test_tenant_id',
             timeout_mins=60,
-            user_creds_id=u'1',
+            user_creds_id='1',
             username='test_username',
             converge=False
         )
-        mock_load.assert_called_once_with(self.ctx, stack=s)
+        mock_load.assert_called_once_with(self.ctx, stack=s,
+                                          check_refresh_cred=True)
         mock_validate.assert_called_once_with()
 
     def test_stack_update_existing_parameters(self):
@@ -264,7 +269,7 @@ class ServiceStackUpdateTest(common.HeatTestCase):
     def test_stack_update_existing_encrypted_parameters(self):
         # Create the stack with encryption enabled
         # On update encrypted_param_names should be used from existing stack
-        hidden_param_template = u'''
+        hidden_param_template = '''
 heat_template_version: 2013-05-23
 parameters:
    param2:
@@ -315,10 +320,10 @@ resources:
                                            update_params,
                                            None, api_args)
             tmpl = mock_stack.call_args[0][2]
-            self.assertEqual({u'param2': u'bar'}, tmpl.env.params)
+            self.assertEqual({'param2': 'bar'}, tmpl.env.params)
             # encrypted_param_names must be passed from existing to new
             # stack otherwise the updated stack won't decrypt the params
-            self.assertEqual([u'param2'], tmpl.env.encrypted_param_names)
+            self.assertEqual(['param2'], tmpl.env.encrypted_param_names)
             self.assertEqual(stk.identifier(), result)
 
     def test_stack_update_existing_parameters_remove(self):
@@ -555,7 +560,8 @@ resources:
         mock_validate.assert_called_once_with()
         mock_tmpl.assert_called_once_with(template, files=None)
         mock_env.assert_called_once_with(params)
-        mock_load.assert_called_once_with(self.ctx, stack=s)
+        mock_load.assert_called_once_with(self.ctx, stack=s,
+                                          check_refresh_cred=True)
         mock_stack.assert_called_once_with(
             self.ctx, stk.name, stk.t,
             convergence=False,
@@ -566,7 +572,7 @@ resources:
             stack_user_project_id='1234',
             strict_validate=True,
             tenant_id='test_tenant_id', timeout_mins=1,
-            user_creds_id=u'1',
+            user_creds_id='1',
             username='test_username',
             converge=False
         )
@@ -699,11 +705,12 @@ resources:
             owner_id=None, parent_resource=None,
             stack_user_project_id='1234', strict_validate=True,
             tenant_id='test_tenant_id',
-            timeout_mins=60, user_creds_id=u'1',
+            timeout_mins=60, user_creds_id='1',
             username='test_username',
             converge=False
         )
-        mock_load.assert_called_once_with(self.ctx, stack=s)
+        mock_load.assert_called_once_with(self.ctx, stack=s,
+                                          check_refresh_cred=True)
         mock_validate.assert_called_once_with()
 
     def test_stack_update_stack_id_equal(self):
@@ -750,9 +757,11 @@ resources:
                          old_stack['A'].properties['Foo'])
 
         self.assertEqual(create_stack['A'].id, old_stack['A'].id)
-        mock_load.assert_called_once_with(self.ctx, stack=s)
+        mock_load.assert_called_once_with(self.ctx, stack=s,
+                                          check_refresh_cred=True)
 
     def test_stack_update_exceeds_resource_limit(self):
+        self.patchobject(context, 'StoredContext')
         stack_name = 'test_stack_update_exceeds_resource_limit'
         params = {}
         tpl = {'HeatTemplateFormatVersion': '2012-12-12',
@@ -818,11 +827,12 @@ resources:
             owner_id=None, parent_resource=None,
             stack_user_project_id='1234', strict_validate=True,
             tenant_id='test_tenant_id',
-            timeout_mins=60, user_creds_id=u'1',
+            timeout_mins=60, user_creds_id='1',
             username='test_username',
             converge=False
         )
-        mock_load.assert_called_once_with(self.ctx, stack=s)
+        mock_load.assert_called_once_with(self.ctx, stack=s,
+                                          check_refresh_cred=True)
         mock_validate.assert_called_once_with()
 
     def test_stack_update_nonexist(self):
@@ -883,10 +893,11 @@ resources:
             stack_user_project_id='1234',
             strict_validate=True,
             tenant_id='test_tenant_id', timeout_mins=60,
-            user_creds_id=u'1', username='test_username',
+            user_creds_id='1', username='test_username',
             converge=False
         )
-        mock_load.assert_called_once_with(self.ctx, stack=s)
+        mock_load.assert_called_once_with(self.ctx, stack=s,
+                                          check_refresh_cred=True)
 
     def test_stack_update_existing_template(self):
         '''Update a stack using the same template.'''
@@ -1141,7 +1152,7 @@ resources:
             disable_rollback=True, nested_depth=0, owner_id=None,
             parent_resource=None, stack_user_project_id='1234',
             strict_validate=True, tenant_id='test_tenant_id', timeout_mins=60,
-            user_creds_id=u'1', username='test_username',
+            user_creds_id='1', username='test_username',
             converge=False
         )
         mock_load.assert_called_once_with(self.ctx, stack=s)
