@@ -13,7 +13,7 @@
 
 from unittest import mock
 
-from cinderclient.v2 import client as cinderclient
+from cinderclient.v3 import client as cinderclient
 
 from heat.engine.clients.os import cinder
 from heat.engine.clients.os import nova
@@ -31,7 +31,9 @@ class VolumeTestCase(common.HeatTestCase):
         super(VolumeTestCase, self).setUp()
         self.fc = fakes_nova.FakeClient()
         self.cinder_fc = cinderclient.Client('username', 'password')
-        self.cinder_fc.volume_api_version = 2
+        self.cinder_fc.volume_api_version = 3
+        self.patchobject(cinder.CinderClientPlugin, 'get_max_microversion',
+                         return_value='3.0')
         self.patchobject(cinder.CinderClientPlugin, '_create',
                          return_value=self.cinder_fc)
         self.patchobject(nova.NovaClientPlugin, 'client',
@@ -49,18 +51,18 @@ class VolumeTestCase(common.HeatTestCase):
 
     def validate_mock_create_server_volume_script(self):
         self.fc.volumes.create_server_volume.assert_called_once_with(
-            device=u'/dev/vdc', server_id=u'WikiDatabase', volume_id='vol-123')
+            device='/dev/vdc', server_id='WikiDatabase', volume_id='vol-123')
 
-    def _mock_create_server_volume_script(self, fva,
-                                          final_status='in-use',
-                                          update=False,
-                                          extra_create_server_volume_mocks=[]):
+    def _mock_create_server_volume_script(
+            self, fva, final_status='in-use', update=False,
+            extra_create_server_volume_mocks=None):
         if not update:
             nova.NovaClientPlugin.client.return_value = self.fc
 
         result = [fva]
-        for m in extra_create_server_volume_mocks:
-            result.append(m)
+        if extra_create_server_volume_mocks:
+            for m in extra_create_server_volume_mocks:
+                result.append(m)
         prev = self.fc.volumes.create_server_volume.side_effect or []
         self.fc.volumes.create_server_volume.side_effect = list(prev) + result
         fv_ready = FakeVolume(final_status, id=fva.id)
@@ -98,7 +100,7 @@ class VolumeTestCase(common.HeatTestCase):
                     size=1, availability_zone=az,
                     description=self.vol_name,
                     name=self.vol_name,
-                    metadata={u'Usage': u'Wiki Data Volume'})
+                    metadata={'Usage': 'Wiki Data Volume'})
         return rsrc
 
     def create_attachment(self, t, stack, resource_name):
@@ -122,6 +124,8 @@ class FakeVolume(object):
 
     def __init__(self, status, **attrs):
         self.status = status
+        self.multiattach = True
+
         for key, value in attrs.items():
             setattr(self, key, value)
         if 'id' not in attrs:
