@@ -16,9 +16,7 @@ from unittest import mock
 
 from heat.common import exception
 from heat.common import grouputils
-from heat.common import short_id
 from heat.common import template_format
-from heat.engine.clients.os import neutron
 from heat.engine import resource
 from heat.engine.resources.openstack.heat import instance_group as instgrp
 from heat.engine import rsrc_defn
@@ -60,7 +58,7 @@ class TestInstanceGroup(common.HeatTestCase):
         self.assertEqual(expected, self.instance_group.child_params())
 
     def test_tags_default(self):
-        expected = [{'Value': u'asg',
+        expected = [{'Value': 'asg',
                      'Key': 'metering.groupname'}]
         self.assertEqual(expected, self.instance_group._tags())
 
@@ -68,7 +66,7 @@ class TestInstanceGroup(common.HeatTestCase):
         self.instance_group.properties.data['Tags'] = [
             {'Key': 'fee', 'Value': 'foo'}]
         expected = [{'Key': 'fee', 'Value': 'foo'},
-                    {'Value': u'asg',
+                    {'Value': 'asg',
                      'Key': 'metering.groupname'}]
         self.assertEqual(expected, self.instance_group._tags())
 
@@ -171,12 +169,9 @@ class TestInstanceGroup(common.HeatTestCase):
 
     def test_instance_group_refid_rsrc_name(self):
         self.instance_group.id = '123'
-
         self.instance_group.uuid = '9bfb9456-3fe8-41f4-b318-9dba18eeef74'
         self.instance_group.action = 'CREATE'
-        expected = '%s-%s-%s' % (self.instance_group.stack.name,
-                                 self.instance_group.name,
-                                 short_id.get_id(self.instance_group.uuid))
+        expected = self.instance_group.name
         self.assertEqual(expected, self.instance_group.FnGetRefId())
 
     def test_instance_group_refid_rsrc_id(self):
@@ -258,8 +253,8 @@ class LoadbalancerReloadTest(common.HeatTestCase):
             'ElasticLoadBalancer',
             'AWS::ElasticLoadBalancing::LoadBalancer',
             {'Instances': ['aaaa', 'bbb'],
-             'Listeners': [{'InstancePort': u'80',
-                            'LoadBalancerPort': u'80',
+             'Listeners': [{'InstancePort': '80',
+                            'LoadBalancerPort': '80',
                             'Protocol': 'HTTP'}],
              'AvailabilityZones': ['nova']}
         )
@@ -268,70 +263,6 @@ class LoadbalancerReloadTest(common.HeatTestCase):
         self.check_mocks(group, mocks)
         lb.update.assert_called_once_with(expected)
 
-    def test_members(self):
-        self.patchobject(neutron.NeutronClientPlugin, 'has_extension',
-                         return_value=True)
-
-        t = template_format.parse(inline_templates.as_template)
-        t['Resources']['ElasticLoadBalancer'] = {
-            'Type': 'OS::Neutron::LoadBalancer',
-            'Properties': {
-                'protocol_port': 8080,
-            }
-        }
-        stack = utils.parse_stack(t)
-
-        lb = stack['ElasticLoadBalancer']
-        lb.update = mock.Mock(return_value=None)
-
-        defn = rsrc_defn.ResourceDefinition(
-            'asg', 'OS::Heat::InstanceGroup',
-            {'Size': 2,
-             'AvailabilityZones': ['zoneb'],
-             "LaunchConfigurationName": "LaunchConfig",
-             "LoadBalancerNames": ["ElasticLoadBalancer"]})
-        group = instgrp.InstanceGroup('asg', defn, stack)
-
-        mocks = self.setup_mocks(group, ['aaaa', 'bbb'])
-        expected = rsrc_defn.ResourceDefinition(
-            'ElasticLoadBalancer',
-            'OS::Neutron::LoadBalancer',
-            {'protocol_port': 8080,
-             'members': ['aaaa', 'bbb']})
-
-        group._lb_reload()
-        self.check_mocks(group, mocks)
-        lb.update.assert_called_once_with(expected)
-
-    def test_lb_reload_invalid_resource(self):
-        t = template_format.parse(inline_templates.as_template)
-        t['Resources']['ElasticLoadBalancer'] = {
-            'Type': 'AWS::EC2::Volume',
-            'Properties': {
-                'AvailabilityZone': 'nova'
-            }
-        }
-        stack = utils.parse_stack(t)
-
-        lb = stack['ElasticLoadBalancer']
-        lb.update = mock.Mock(return_value=None)
-
-        defn = rsrc_defn.ResourceDefinition(
-            'asg', 'OS::Heat::InstanceGroup',
-            {'Size': 2,
-             'AvailabilityZones': ['zoneb'],
-             "LaunchConfigurationName": "LaunchConfig",
-             "LoadBalancerNames": ["ElasticLoadBalancer"]})
-        group = instgrp.InstanceGroup('asg', defn, stack)
-
-        self.setup_mocks(group, ['aaaa', 'bbb'])
-        error = self.assertRaises(exception.Error,
-                                  group._lb_reload)
-        self.assertEqual(
-            "Unsupported resource 'ElasticLoadBalancer' in "
-            "LoadBalancerNames",
-            str(error))
-
     def test_lb_reload_static_resolve(self):
         t = template_format.parse(inline_templates.as_template)
         properties = t['Resources']['ElasticLoadBalancer']['Properties']
