@@ -25,6 +25,7 @@ from heat.engine.clients.os import swift as swift_plugin
 from heat.engine import environment
 from heat.engine import resource
 from heat.engine.resources.openstack.heat import wait_condition_handle as h_wch
+from heat.engine import scheduler
 from heat.engine import stack as parser
 from heat.engine import template as tmpl
 from heat.objects import resource as resource_objects
@@ -141,8 +142,9 @@ class HeatWaitConditionTest(common.HeatTestCase):
 
     def create_stack(self, stack_id=None,
                      template=test_template_heat_waitcondition_count,
-                     params={},
+                     params=None,
                      stub=True, stub_status=True):
+        params = params or {}
         temp = template_format.parse(template)
         template = tmpl.Template(temp,
                                  env=environment.Environment(params))
@@ -280,7 +282,7 @@ class HeatWaitConditionTest(common.HeatTestCase):
                          'status': 'SUCCESS', 'id': '456'}
         ret = handle.handle_signal(details=test_metadata)
         wc_att = rsrc.FnGetAtt('data')
-        self.assertEqual(json.loads(u'{"123": "foo", "456": "dog"}'),
+        self.assertEqual(json.loads('{"123": "foo", "456": "dog"}'),
                          json.loads(wc_att))
         self.assertEqual('status:SUCCESS reason:cat', ret)
         mock_get_status.assert_called_once()
@@ -298,7 +300,7 @@ class HeatWaitConditionTest(common.HeatTestCase):
                          'status': 'SUCCESS'}
         ret = handle.handle_signal(details=test_metadata)
         wc_att = rsrc.FnGetAtt('data')
-        self.assertEqual(json.loads(u'{"1": "foo", "2": "dog"}'),
+        self.assertEqual(json.loads('{"1": "foo", "2": "dog"}'),
                          json.loads(wc_att))
         self.assertEqual('status:SUCCESS reason:cat', ret)
         mock_get_status.assert_called_once()
@@ -313,7 +315,7 @@ class HeatWaitConditionTest(common.HeatTestCase):
 
         handle.handle_signal()
         wc_att = rsrc.FnGetAtt('data')
-        self.assertEqual(json.loads(u'{"1": null, "2": null}'),
+        self.assertEqual(json.loads('{"1": null, "2": null}'),
                          json.loads(wc_att))
         mock_get_status.assert_called_once()
 
@@ -331,7 +333,7 @@ class HeatWaitConditionTest(common.HeatTestCase):
         expected = 'status:SUCCESS reason:Signal 2 received'
         self.assertEqual(expected, ret)
         wc_att = rsrc.FnGetAtt('data')
-        self.assertEqual(json.loads(u'{"1": null, "2": null}'),
+        self.assertEqual(json.loads('{"1": null, "2": null}'),
                          json.loads(wc_att))
         mock_get_status.assert_called_once()
 
@@ -489,5 +491,7 @@ class HeatWaitConditionTest(common.HeatTestCase):
 
         handle = self.stack['update_wait_handle']
         self.assertEqual((handle.CREATE, handle.COMPLETE), handle.state)
+
         self.assertRaises(
-            resource.UpdateReplace, handle.update, None, None)
+            resource.UpdateReplace,
+            scheduler.TaskRunner(handle.update, handle.t))
