@@ -64,7 +64,7 @@ class TestRequestContext(common.HeatTestCase):
             aws_creds=self.ctx.get('aws_creds'),
             project_name=self.ctx.get('tenant'),
             project_id=self.ctx.get('tenant_id'),
-            user=self.ctx.get('user_id'),
+            user_id=self.ctx.get('user_id'),
             auth_url=self.ctx.get('auth_url'),
             roles=self.ctx.get('roles'),
             show_deleted=self.ctx.get('show_deleted'),
@@ -113,7 +113,7 @@ class TestRequestContext(common.HeatTestCase):
             aws_creds=ctx_origin.get('aws_creds'),
             project_name=ctx_origin.get('tenant'),
             project_id=ctx_origin.get('tenant_id'),
-            user=ctx_origin.get('user_id'),
+            user_id=ctx_origin.get('user_id'),
             auth_url=ctx_origin.get('auth_url'),
             roles=ctx_origin.get('roles'),
             show_deleted=ctx_origin.get('show_deleted'),
