@@ -21,7 +21,8 @@ from oslo_utils import timeutils
 from heat.common import exception
 from heat.common import template_format
 from heat.common import timeutils as heat_timeutils
-from heat.db.sqlalchemy import models
+from heat.db import api as db_api
+from heat.db import models
 from heat.engine import api
 from heat.engine.cfn import parameters as cfn_param
 from heat.engine import event
@@ -332,10 +333,11 @@ class FormatTest(common.HeatTestCase):
     def test_format_event_legacy_prop_data(self):
         event = self._dummy_event(res_properties=None)
         # legacy location
-        db_obj = self.stack.context.session.query(
-            models.Event).filter_by(id=event.id).first()
-        db_obj.update({'resource_properties': {'legacy_k1': 'legacy_v1'}})
-        db_obj.save(self.stack.context.session)
+        with db_api.context_manager.writer.using(self.stack.context):
+            db_obj = self.stack.context.session.query(
+                models.Event).filter_by(id=event.id).first()
+            db_obj.update({'resource_properties': {'legacy_k1': 'legacy_v1'}})
+            db_obj.save(self.stack.context.session)
         event_legacy = event_object.Event.get_all_by_stack(self.context,
                                                            self.stack.id)[0]
         formatted = api.format_event(event_legacy, self.stack.identifier())
@@ -522,7 +524,6 @@ class FormatTest(common.HeatTestCase):
                              tmpl, stack_id=str(uuid.uuid4()))
         info = api.format_stack(stack)
 
-        # Should be 'bar,baz' NOT "[u'bar', u'baz']"
         self.assertEqual('bar,baz', info['parameters']['foo'])
 
     def test_format_stack_params_json(self):
@@ -539,7 +540,7 @@ class FormatTest(common.HeatTestCase):
                              tmpl, stack_id=str(uuid.uuid4()))
         info = api.format_stack(stack)
 
-        # Should be '{"bar": "baz"}' NOT "{u'bar': u'baz'}"
+        # Should be '{"bar": "baz"}' NOT "{'bar': 'baz'}"
         self.assertEqual('{"bar": "baz"}', info['parameters']['foo'])
 
 
