@@ -209,8 +209,8 @@ class DepAttrsTest(common.HeatTestCase):
                            'CResource': set()})),
         ('nested_attr',
             dict(tmpl=tmpl6,
-                 expected={'AResource': set([(u'list', 1),
-                                             (u'nested_dict', u'dict', u'b')]),
+                 expected={'AResource': set([('list', 1),
+                                             ('nested_dict', 'dict', 'b')]),
                            'BResource': set([])})),
         ('several_res_several_attrs_and_all_attrs',
             dict(tmpl=tmpl7,
